==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/help/ja-sjis/chkfnrHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* R}hwv,man,musahi GUI ʃbZ[WǗ                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* R}h̃^Cg                                                         */
/* R}hwv̍ŏ̍sɕ\\                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "͈͂ɂt@C݃`FbN"

/*----------------------------------------------------------------------------*/
/* p[^                                                                 */
/* R}hwv USAGE:Ƃ"L[[h XXXT"\\ ex)-k L[ږXg*/
/* flag̃IvV̓R}hwvOPTIONS)Ƃĕ\\ ex)-z : Wo͂̈k*/
/*----------------------------------------------------------------------------*/
/*-F*/
#define RNG1T "͈͂̃X^[g"
#define RNG1C "͈͂̃X^[g"

/*-T*/
#define RNG2T "͈͂̃Gh"
#define RNG2C "͈͂̃Gh"

/*-c*/
#define EQLT "l̈"
#define EQLC "l̈"
#define EQLS "okok,okng,ngok,ngng"

/*-D*/
#define DLMT "f~^"
#define DLMC "t@Cɂ͈͂؂镶"

/*-i*/
#define INFT "`FbNt@C"
#define INFC "ChJ[hp"

/*----------------------------------------------------------------------------*/
/* v                                                                       */
/* R}hwvSUMMARY:Ƃĕ\\                                     */
/* HTMLwvmanɂ́AHELPD̏Ɍ`ŕ\\                   */
/*----------------------------------------------------------------------------*/
#define HELPS "t@Cf~^(ftHg:-)ŋ؂ꂽ͈͂ƂčlA-F,-TŎw肵͈͂t@C͈͂ƏdȂĂȂ0,Ȃ΂PԂB"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
 chkfnr -i '/tmp/*' -F100 -T200\n\
 chkfnr -i '/tmp/*' -F100 -T200 -e okng\n\
"

/*----------------------------------------------------------------------------*/
/* QƃR}h(KJ}ŋ؂A󔒂͗pȂ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR ""

/*----------------------------------------------------------------------------*/
/* ҂ɂ                                                               */
/* R}hwvɂ͕\\Ȃ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* oO|[g                                                               */
/* o^΃R}hwvBUG REPORT:ɕ\\B                  */
/* o^Ȃ(#define HELPB "")\\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* z[y[W                                                               */
/* o^΃R}hwvINFORMATION:ɕ\\B                 */
/* o^Ȃ(#define HELPH "")\\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH

==> musashi-core-1.0.4-pre6.tar.gz: musashi-core-1.0.4-pre6/help/ja-sjis/chkfnrHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* R}hwv,man,musahi GUI ʃbZ[WǗ                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* R}h̃^Cg                                                         */
/* R}hwv̍ŏ̍sɕ\                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "͈͂ɂt@C݃`FbN"

/*----------------------------------------------------------------------------*/
/* p[^                                                                 */
/* R}hwv USAGE:Ƃ"L[[h XXXT"\ ex)-k L[ږXg*/
/* flag̃IvV̓R}hwvOPTIONS)Ƃĕ\ ex)-z : Wo͂̈k*/
/*----------------------------------------------------------------------------*/
/*-F*/
#define RNG1T "͈͂̃X^[g"
#define RNG1C "͈͂̃X^[g"

/*-T*/
#define RNG2T "͈͂̃Gh"
#define RNG2C "͈͂̃Gh"

/*-c*/
#define EQLT "l̈"
#define EQLC "l̈"
#define EQLS "okok,okng,ngok,ngng"

/*-D*/
#define DLMT "f~^"
#define DLMC "t@Cɂ͈͂؂镶"

/*-i*/
#define INFT "`FbNt@C"
#define INFC "ChJ[hp"

/*----------------------------------------------------------------------------*/
/* v                                                                       */
/* R}hwvSUMMARY:Ƃĕ\                                     */
/* HTMLwvmanɂ́AHELPD̏Ɍ`ŕ\                   */
/*----------------------------------------------------------------------------*/
#define HELPS "t@Cf~^(ftHg:-)ŋ؂ꂽ͈͂ƂčlA-F,-TŎw肵͈͂t@C͈͂ƏdȂĂȂ0,Ȃ΂PԂB"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
 chkfnr -i '/tmp/*' -F100 -T200\n\
 chkfnr -i '/tmp/*' -F100 -T200 -e okng\n\
"

/*----------------------------------------------------------------------------*/
/* QƃR}h(KJ}ŋ؂A󔒂͗pȂ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR ""

/*----------------------------------------------------------------------------*/
/* ҂ɂ                                                               */
/* R}hwvɂ͕\Ȃ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* oO|[g                                                               */
/* o^΃R}hwvBUG REPORT:ɕ\B                  */
/* o^Ȃ(#define HELPB "")\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* z[y[W                                                               */
/* o^΃R}hwvINFORMATION:ɕ\B                 */
/* o^Ȃ(#define HELPH "")\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH
